@@ -852,7 +852,23 @@ class AsyncClient(BaseClient):
         page_size	false	int	不填默认20，不得多于50	20	[1-50]
         """
         data = package_data(remove_key(locals()))
-        return await self._request_future_private_api("post", "contract_openorders", data=data)
+        return await self._request_future_private_api("post", "contract_matchresults", data=data)
+
+    async def future_match_result_exact(self, symbol, trade_type, contract_code=None, start_time=None, end_time=None,
+                                        from_id=None, size=20, direct="prev"):
+        """
+        组合查询历史成交记录接口
+        symbol	true	string	品种代码	"BTC","ETH"...
+        trade_type	true	int	交易类型	0:全部,1:买入开多,2: 卖出开空,3: 买入平空,4: 卖出平多,5: 卖出强平,6: 买入强平
+        contract_code	false	string	合约code
+        start_time	false	long	起始时间（时间戳，单位毫秒）	详见备注
+        end_time	false	long	结束时间（时间戳，单位毫秒）	详见备注
+        from_id	false	long	查询起始id（取返回数据的query_id字段）
+        size	false	int	数据条数,默认取20，最大50	[1-50]
+        direct	false	string	查询方向	prev 向前；next 向后；默认值取prev
+        """
+        data = package_data(remove_key(locals()))
+        return await self._request_future_private_api("post", "contract_matchresults_exact", data=data)
 
     async def future_lightning_close_position(self, volume, direction, symbol=None, contract_type=None,
                                               contract_code=None, client_order_id=None,
