@@ -117,5 +117,10 @@ class OrderPriceType:
     FOK = 'fok'
 
 
+class Side:
+    BUY = "buy"
+    SELL = "sell"
+
+
 
 
